@@ -21,6 +21,8 @@ else:
 
 __all__ = (
     "ConnectionStateType",
+    "ConnectionStatusType",
+    "ConnectionTypeType",
     "CustomerGatewayAssociationStateType",
     "DescribeGlobalNetworksPaginatorName",
     "DeviceStateType",
@@ -29,12 +31,22 @@ __all__ = (
     "GetDevicesPaginatorName",
     "GetLinkAssociationsPaginatorName",
     "GetLinksPaginatorName",
+    "GetNetworkResourceCountsPaginatorName",
+    "GetNetworkResourceRelationshipsPaginatorName",
+    "GetNetworkResourcesPaginatorName",
+    "GetNetworkTelemetryPaginatorName",
     "GetSitesPaginatorName",
     "GetTransitGatewayConnectPeerAssociationsPaginatorName",
     "GetTransitGatewayRegistrationsPaginatorName",
     "GlobalNetworkStateType",
     "LinkAssociationStateType",
     "LinkStateType",
+    "RouteAnalysisCompletionReasonCodeType",
+    "RouteAnalysisCompletionResultCodeType",
+    "RouteAnalysisStatusType",
+    "RouteStateType",
+    "RouteTableTypeType",
+    "RouteTypeType",
     "SiteStateType",
     "TransitGatewayConnectPeerAssociationStateType",
     "TransitGatewayRegistrationStateType",
@@ -44,6 +56,8 @@ __all__ = (
 
 
 ConnectionStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
+ConnectionStatusType = Literal["DOWN", "UP"]
+ConnectionTypeType = Literal["BGP", "IPSEC"]
 CustomerGatewayAssociationStateType = Literal["AVAILABLE", "DELETED", "DELETING", "PENDING"]
 DescribeGlobalNetworksPaginatorName = Literal["describe_global_networks"]
 DeviceStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
@@ -52,6 +66,10 @@ GetCustomerGatewayAssociationsPaginatorName = Literal["get_customer_gateway_asso
 GetDevicesPaginatorName = Literal["get_devices"]
 GetLinkAssociationsPaginatorName = Literal["get_link_associations"]
 GetLinksPaginatorName = Literal["get_links"]
+GetNetworkResourceCountsPaginatorName = Literal["get_network_resource_counts"]
+GetNetworkResourceRelationshipsPaginatorName = Literal["get_network_resource_relationships"]
+GetNetworkResourcesPaginatorName = Literal["get_network_resources"]
+GetNetworkTelemetryPaginatorName = Literal["get_network_telemetry"]
 GetSitesPaginatorName = Literal["get_sites"]
 GetTransitGatewayConnectPeerAssociationsPaginatorName = Literal[
     "get_transit_gateway_connect_peer_associations"
@@ -60,6 +78,24 @@ GetTransitGatewayRegistrationsPaginatorName = Literal["get_transit_gateway_regis
 GlobalNetworkStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
 LinkAssociationStateType = Literal["AVAILABLE", "DELETED", "DELETING", "PENDING"]
 LinkStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
+RouteAnalysisCompletionReasonCodeType = Literal[
+    "BLACKHOLE_ROUTE_FOR_DESTINATION_FOUND",
+    "CYCLIC_PATH_DETECTED",
+    "INACTIVE_ROUTE_FOR_DESTINATION_FOUND",
+    "MAX_HOPS_EXCEEDED",
+    "NO_DESTINATION_ARN_PROVIDED",
+    "POSSIBLE_MIDDLEBOX",
+    "ROUTE_NOT_FOUND",
+    "TRANSIT_GATEWAY_ATTACHMENT_ATTACH_ARN_NO_MATCH",
+    "TRANSIT_GATEWAY_ATTACHMENT_NOT_FOUND",
+    "TRANSIT_GATEWAY_ATTACHMENT_NOT_IN_TRANSIT_GATEWAY",
+    "TRANSIT_GATEWAY_ATTACHMENT_STABLE_ROUTE_TABLE_NOT_FOUND",
+]
+RouteAnalysisCompletionResultCodeType = Literal["CONNECTED", "NOT_CONNECTED"]
+RouteAnalysisStatusType = Literal["COMPLETED", "FAILED", "RUNNING"]
+RouteStateType = Literal["ACTIVE", "BLACKHOLE"]
+RouteTableTypeType = Literal["TRANSIT_GATEWAY_ROUTE_TABLE"]
+RouteTypeType = Literal["PROPAGATED", "STATIC"]
 SiteStateType = Literal["AVAILABLE", "DELETING", "PENDING", "UPDATING"]
 TransitGatewayConnectPeerAssociationStateType = Literal[
     "AVAILABLE", "DELETED", "DELETING", "PENDING"
@@ -100,6 +136,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -361,6 +398,10 @@ PaginatorName = Literal[
     "get_devices",
     "get_link_associations",
     "get_links",
+    "get_network_resource_counts",
+    "get_network_resource_relationships",
+    "get_network_resources",
+    "get_network_telemetry",
     "get_sites",
     "get_transit_gateway_connect_peer_associations",
     "get_transit_gateway_registrations",
